var a00875 =
[
    [ "RefinerSurfaceFactoryBase", "a00916.html", "a00916" ],
    [ "RefinerSurfaceFactory&lt; CACHE_TYPE &gt;", "a00920.html", "a00920" ]
];